@@ -105,7 +105,7 @@ class CodeBlock(VGroup):
     def __init__(
             self, 
             text: str, 
-            language: ProgrammingLanguage | None, 
+            language: ProgrammingLanguage | None = None, 
             theme: Theme = OneDark,
             font: str = "consolas",
             **kwargs: object
@@ -158,22 +158,26 @@ class CodeBlock(VGroup):
             fill_opacity = 1
         )
 
-        lang_name = MarkupText(
-            f'<span font="{font}">{language.name}</span>',
-             z_index = 3
-        ).next_to(background_rect, UP).set_color(language.color)
-        lang_name.scale(0.3, about_point=lang_name.get_corner(DOWN + LEFT))
+        if language:
+            lang_name = MarkupText(
+                f'<span font="{font}">{language.name}</span>',
+                z_index = 3
+            ).next_to(background_rect, UP).set_color(language.color)
+            lang_name.scale(0.3, about_point=lang_name.get_corner(DOWN + LEFT))
 
-        lang_background = BackgroundRectangle(lang_name, color="#282C34", buff=0.15, fill_opacity=1)
-        pos = background_rect.get_corner(UP + LEFT) + np.array([lang_background.width/2, lang_background.height/2 - 0.005, 0])
+            lang_background = BackgroundRectangle(lang_name, color="#282C34", buff=0.15, fill_opacity=1)
+            pos = background_rect.get_corner(UP + LEFT) + np.array([lang_background.width/2, lang_background.height/2 - 0.005, 0])
 
-        VGroup(lang_name, lang_background).move_to(pos)
-        super().__init__(background_rect, markup, lang_background, lang_name, **kwargs)
+            VGroup(lang_name, lang_background).move_to(pos)
+
+            self.code_background = background_rect
+            self.title_background = lang_background
+
+            super().__init__(background_rect, markup, lang_background, lang_name, **kwargs)
+        else: super().__init__(background_rect, markup, **kwargs)
 
         self.code = markup
         self.title = lang_name
-        self.code_background = background_rect
-        self.title_background = lang_background
 
     def create(self, **kwargs) -> tuple[FadeIn, AddTextLetterByLetter, FadeIn, AddTextLetterByLetter]:
         """
@@ -184,13 +188,18 @@ class CodeBlock(VGroup):
         ```
         By default the animation will `FadeIn` the `background` and `title_background`, and `AddTextLetterByLetter` the `code` and `title`. 
         """
-        return (
+        if self.title and self.title_background: return (
             FadeIn(self.code_background, **kwargs), 
             AddTextLetterByLetter(self.code, **kwargs), 
             FadeIn(self.title_background, **kwargs), 
             AddTextLetterByLetter(self.title, **kwargs)
         )
 
+        return (
+            FadeIn(self.code_background, **kwargs), 
+            AddTextLetterByLetter(self.code, **kwargs), 
+        )
+
     def uncreate(self, **kwargs):
         """
         Return a tuple of animations for uncreating the code block. Use such as:
@@ -200,13 +209,18 @@ class CodeBlock(VGroup):
         ```
         By default the animation will `FadeOut` the `background` and `title_background`, and `Uncreate` the `code` and `title`. 
         """
-        return (
+        if self.title and self.title_background: return (
             FadeOut(self.code_background, **kwargs), 
             Uncreate(self.code, **kwargs), 
             FadeOut(self.title_background, **kwargs), 
             Uncreate(self.title, **kwargs)
         )
 
+        return (
+            FadeOut(self.code_background, **kwargs), 
+            Uncreate(self.code, **kwargs), 
+        )
+
 
 C = ProgrammingLanguage("C")
 """The `C` programming language, used to render `C` code in `CodeBlocks`"""
